@@ -1,7 +1,7 @@
-package t::TestYAMLTests;
+package TestYAMLTests;
 use lib 'inc';
 use Test::Base -Base;
-@t::TestYAMLTests::EXPORT = qw(Load Dump LoadFile DumpFile n2y y2n nyny get_block_by_name);
+@TestYAMLTests::EXPORT = qw(Load Dump n2y y2n nyny get_block_by_name);
 
 sub load_config() {
     my $config_file = shift;
@@ -23,11 +23,7 @@ my $yaml_module;
 BEGIN {
     my $config = load_config('t/yaml_tests.yaml');
     if ($config->{use_blib}) {
-      if ($ENV{PERL_CORE}) {
-        @INC = ('../../lib', '../../lib/auto', 'inc');
-      } else {
         eval "use blib; 1" or die $@;
-      }
     }
     $yaml_module = $ENV{PERL_YAML_TESTS_MODULE} || $config->{yaml_module}
       or die "Can't determine which YAML module to use for this test.";
@@ -101,33 +97,18 @@ sub Dump() {
     no strict 'refs';
     &{$yaml_module . "::Dump"}(@_);
 }
-sub LoadFile() {
-    no strict 'refs';
-    &{$yaml_module . "::LoadFile"}(@_);
-}
-sub DumpFile() {
-    no strict 'refs';
-    &{$yaml_module . "::DumpFile"}(@_);
-}
 
 no_diff;
 delimiters ('===', '+++');
 
-package t::TestYAMLTests::Filter;
+package TestYAMLTests::Filter;
 use Test::Base::Filter -Base;
 
 sub load_yaml {
-    t::TestYAMLTests::Load(@_);
+    TestYAMLTests::Load(@_);
 }
 
 sub dump_yaml {
-    t::TestYAMLTests::Dump(@_);
+    TestYAMLTests::Load(@_);
 }
 
-sub loadfile_yaml {
-    t::TestYAMLTests::LoadFile(@_);
-}
-
-sub dumpfile_yaml {
-    t::TestYAMLTests::DumpFile(@_);
-}
